import { forwardRef, useEffect } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import useEventListener from '@s-ui/react-hooks/lib/useEventListener';
import MoleculeDrawerOverlay from './Overlay.js';
import { ANIMATION_DURATION as moleculeDrawerAnimationDuration, BASE_CLASS, PLACEMENTS as moleculeDrawerPlacements, SIZES as moleculeDrawerSizes } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
var DRAWER_CONTENT_CLASS = BASE_CLASS + "-content";
var MoleculeDrawer = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _cx;
  var _ref$animationDuratio = _ref.animationDuration,
    animationDuration = _ref$animationDuratio === void 0 ? moleculeDrawerAnimationDuration.FAST : _ref$animationDuratio,
    children = _ref.children,
    _ref$isOpen = _ref.isOpen,
    isOpen = _ref$isOpen === void 0 ? false : _ref$isOpen,
    _ref$isPageScrollable = _ref.isPageScrollable,
    isPageScrollable = _ref$isPageScrollable === void 0 ? true : _ref$isPageScrollable,
    onOpen = _ref.onOpen,
    onClose = _ref.onClose,
    _ref$placement = _ref.placement,
    placement = _ref$placement === void 0 ? moleculeDrawerPlacements.LEFT : _ref$placement,
    _ref$size = _ref.size,
    size = _ref$size === void 0 ? moleculeDrawerSizes.AUTO : _ref$size,
    target = _ref.target,
    _ref$closeOnOutsideCl = _ref.closeOnOutsideClick,
    closeOnOutsideClick = _ref$closeOnOutsideCl === void 0 ? false : _ref$closeOnOutsideCl;
  useEffect(function () {
    if (target !== undefined) {
      target.current.style.position = 'relative';
      target.current.style.overflow = 'hidden';
    }
  }, [target]);
  useEffect(function () {
    if (isOpen && !isPageScrollable) blockScrollPage();else if (!isOpen && !isPageScrollable) enableScrollPage();
    if (!isPageScrollable) return function () {
      return enableScrollPage();
    };
  }, [isOpen, isPageScrollable]);
  var closeDrawer = function closeDrawer(event) {
    if (!isPageScrollable) enableScrollPage();
    onClose(event, {
      isOpen: false
    });
  };
  useEventListener('keydown', function (event) {
    if (isOpen === false) return;
    if (event.key === 'Escape') {
      closeDrawer(event);
    }
  });
  useEventListener('mousedown', function (event) {
    if (isOpen === false || !forwardedRef || !closeOnOutsideClick) return;
    if (!forwardedRef.current.contains(event.target)) {
      closeDrawer(event);
    }
  });
  var blockScrollPage = function blockScrollPage() {
    return document.body.style.overflow = 'hidden';
  };
  var enableScrollPage = function enableScrollPage() {
    return document.body.style.overflow = 'auto';
  };
  return /*#__PURE__*/_jsx("div", {
    className: cx(DRAWER_CONTENT_CLASS, DRAWER_CONTENT_CLASS + "--placement-" + placement, DRAWER_CONTENT_CLASS + "--size-" + size, DRAWER_CONTENT_CLASS + "--animationDuration-" + animationDuration, DRAWER_CONTENT_CLASS + "--state-" + (isOpen ? 'opened' : 'closed'), (_cx = {}, _cx[DRAWER_CONTENT_CLASS + "--placement"] = typeof target === 'undefined', _cx)),
    ref: forwardedRef,
    children: children
  });
});
MoleculeDrawer.displayName = 'MoleculeDrawer';
export default MoleculeDrawer;
export { MoleculeDrawer, MoleculeDrawerOverlay };
export { moleculeDrawerPlacements };
export { moleculeDrawerSizes };
export { moleculeDrawerAnimationDuration };